The Famed HPC Report

### A Reasonably Decent Example of My Brain In Action

I was just going to link to the pdf itself, however I realised wanted to talk about the report itself too lmao. If you just want to see the report, it's available here (with my group-mate's name redacted as I haven't asked him for permission, along with both of our student ID's), otherwise, get ready for some rambling.

Firstly, yes, I went slightly overkill with the Catppuccin theming, but I did really enjoy relearning Matplotlib (which, yes, was also themed lol).

My workflow for this was slightly insane, as my group-mate, who was writing up the code implementation explanation did not want to learn Latex, and so I had to find a way to convert Markdown to Latex, while getting the theming to work properly.
Thankfully, pandoc exists, and so`pandoc --listings -f markdown -t latex -o report.tex report.md`

Ironically, I didn't actually use listings in the end report, as I found the minted package with Pygments to work a bit better, and (importantly) already had a Catppuccin theme! So, the next step was to (tediously) go through the generated tex file, replacing every listed call with an equivalent minted version (a rough example would be to replace `\passthrough{\lstinline!make release!}` with `\textbf{\mintinline{bash}{make release}}`). Also, huge thank you to Yukai Chou, who wrote a lovely latex function I borrowed to get some parts of minted to work (code here)!

Once this, and the rest of the small things needed to touch up the document (so many things) had been done, I could then simply generate a pdf from the tex file using `pdflatex --shell-escape report.tex` . If you want to see what my tex file looked like at the end of it all, I have attached it here.

You may be wondering, surely this must have taken hours, just to get a nice colour-scheme on a report... and you would be right to wonder, I genuinely do not know why I put myself through this. On the upside, I guess I get to ramble about it here, and we did get a good grade for presentation (to be honest, we got 100% in the entire assessment, so I am going to tell myself without the theming we might have only got 14/15 or something). Oh, and no, the hours spent do not include setting up Matplotlib to produce graphs that matched the colour-scheme - that actually wasn't too bad, and using Matplotlib was easier for me because it meant I was able to create the graphs using code, which worked well for my brain lol.